CircomLib class

Constructors

CircomLib()

Properties

cstringFree ↔ CStringFree
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lib → DynamicLibrary
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hashPoseidon(String txCompressedData, String toEthAddr, String? toBjjAy, String? rqTxCompressedDatav2, String? rqToEthAddr, String? rqToBjjAy) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packPoint(String pointX, String pointY) → String
packSignature(String signature) → String
prv2pub(String privateKey) → String
signPoseidon(String privateKey, String msg) → String
toString() → String
A string representation of this object.
inherited
unpackPoint(String compressedPoint) → List<String>?
unpackSignature(String compressedSignature) → String
verifyPoseidon(String publicKey, String compressedSignature, String msg) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited