Batch class

Constructors

Batch({int? itemId, int? batchNum, int? ethereumBlockNum, String? ethereumBlockHash, String? timestamp, String? forgerAddr, dynamic collectedFees, double? historicTotalCollectedFeesUSD, String? stateRoot, int? numAccounts, String? exitRoot, int? forgeL1TransactionsNum, int? slotNum, int? forgedTransactions})
Batch.fromJson(Map<String, dynamic> json)
factory

Properties

batchNum → int?
final
collectedFees → dynamic
final
ethereumBlockHash → String?
final
ethereumBlockNum → int?
final
exitRoot → String?
final
forgedTransactions → int?
final
forgeL1TransactionsNum → int?
final
forgerAddr → String?
final
hashCode → int
The hash code for this object.
no setterinherited
historicTotalCollectedFeesUSD → double?
final
itemId → int?
final
numAccounts → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotNum → int?
final
stateRoot → String?
final
timestamp → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited