Bucket class

Constructors

Bucket({String? ceilUSD, String? blockStamp, String? withdrawals, String? rateBlocks, String? rateWithdrawals, String? maxWithdrawals})
Bucket.fromJson(Map<String, dynamic> json)
factory

Properties

blockStamp → String?
final
ceilUSD → String?
final
hashCode → int
The hash code for this object.
no setterinherited
maxWithdrawals → String?
final
rateBlocks → String?
final
rateWithdrawals → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withdrawals → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited