Exit class

Constructors

Exit({int? batchNum, String? accountIndex, int? itemId, MerkleProof? merkleProof, String? balance, int? instantWithdraw, int? delayedWithdrawRequest, int? delayedWithdraw, Token? token, String? bjj, String? hezEthereumAddress})
Exit.fromJson(Map<String, dynamic> json)
factory
Exit.fromL1Transaction(dynamic transaction)
factory
Exit.fromTransaction(PoolTransaction transaction)
factory

Properties

accountIndex → String?
final
balance ↔ String?
getter/setter pair
batchNum → int?
final
bjj → String?
final
delayedWithdraw → int?
final
delayedWithdrawRequest ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hezEthereumAddress → String?
final
instantWithdraw → int?
final
itemId → int?
final
merkleProof → MerkleProof?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Token?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited