PoolTransaction class

Constructors

PoolTransaction({String? amount, int? fee, String? fromAccountIndex, String? fromBJJ, String? fromHezEthereumAddress, String? id, String? info, int? nonce, String? requestAmount, int? requestFee, String? requestFromAccountIndex, String? requestNonce, String? requestToAccountIndex, String? requestToBJJ, String? requestToHezEthereumAddress, String? requestTokenId, String? signature, String? state, String? timestamp, String? toAccountIndex, String? toBjj, String? toHezEthereumAddress, Token? token, String? type})
PoolTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
final
fee → int?
final
fromAccountIndex → String?
final
fromBJJ → String?
final
fromHezEthereumAddress → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
info → String?
final
nonce → int?
final
requestAmount → String?
final
requestFee → int?
final
requestFromAccountIndex → String?
final
requestNonce → String?
final
requestToAccountIndex → String?
final
requestToBJJ → String?
final
requestToHezEthereumAddress → String?
final
requestTokenId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → String?
final
state → String?
final
timestamp → String?
final
toAccountIndex → String?
final
toBjj → String?
final
toHezEthereumAddress → String?
final
token → Token?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited