StateResponse class

Constructors

StateResponse({Network? network, Metrics? metrics, Rollup? rollup, LinkedHashMap<String, dynamic>? auction, WithdrawalDelayer? withdrawalDelayer, RecommendedFee? recommendedFee})
StateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

auction → LinkedHashMap<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
metrics → Metrics?
final
network → Network?
final
recommendedFee → RecommendedFee?
final
rollup → Rollup?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withdrawalDelayer → WithdrawalDelayer?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited