Token class

Constructors

Token({double? USD, int? decimals, String? ethereumAddress, int? ethereumBlockNum, String? fiatUpdate, int? id, int? itemId, String? name, String? symbol})
Token.fromJson(Map<String, dynamic> json)
factory

Properties

decimals → int?
final
ethereumAddress ↔ String?
getter/setter pair
ethereumBlockNum → int?
final
fiatUpdate → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
itemId → int?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → String?
final
USD → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited