Transaction class

Constructors

Transaction({String? id, String? type, String? fromAccountIndex, String? toAccountIndex, String? toEthereumAddress, String? toBjj, int? tokenId, String? amount, int? fee, int? nonce, String? state, String? signature, String? timestamp, int? batchNum, String? rqFromAccountIndex, String? rqToAccountIndex, String? rqToEthereumAddress, String? rqToBJJ, int? rqTokenId, String? rqAmount, int? rqFee, int? rqNonce, String? tokenSymbol})
Transaction.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
final
batchNum → int?
final
fee → int?
final
fromAccountIndex → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
nonce → int?
final
rqAmount → String?
final
rqFee → int?
final
rqFromAccountIndex → String?
final
rqNonce → int?
final
rqToAccountIndex → String?
final
rqToBJJ → String?
final
rqToEthereumAddress → String?
final
rqTokenId → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → String?
final
state → String?
final
timestamp → String?
final
toAccountIndex → String?
final
toBjj → String?
final
toEthereumAddress → String?
final
tokenId → int?
final
tokenSymbol → String?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited