TypedDataDomain class

Constructors

TypedDataDomain(String name, String version, BigInt chainId, EthereumAddress verifyingContract, {String? salt})

Properties

chainId ↔ BigInt
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt ↔ String?
getter/setter pair
verifyingContract ↔ EthereumAddress
getter/setter pair
version ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited